@@ -17,7 +17,11 @@ CONFIG_NAME = '.quera_config'
 
 @cached
 def __get_current_file_id():
-    response = requests.get('http://172.28.0.2:9000/api/sessions').json()
+    try:
+        response = requests.get('http://172.28.0.2:9000/api/sessions').json()
+    except requests.exceptions.JSONDecodeError:
+        print('Colab Error: please call quera support; colab api session is not working.')
+        return None
     if len(response) > 0 and 'path' in response[0] and 'fileId=' in response[0]['path']:
         _file_id = response[0]['path'].split('=', 1)[1]
         return urllib.parse.unquote(_file_id)
